pub struct TransitionState {
pub pre_state: SuperRoot,
pub pending_progress: Vec<OptimisticBlock>,
pub step: u64,
}Expand description
The TransitionState is a super-structure of the SuperRoot that represents the progress of a pending superchain state transition from one SuperRoot to the next.
Fields
pre_state: SuperRootThe canonical pre-state super root commitment.
pending_progress: Vec<OptimisticBlock>The progress that has been made in the pending superchain state transition.
step: u64The step number of the pending superchain state transition.
Implementations
Sourceimpl TransitionState
impl TransitionState
Sourcepub const fn new(
pre_state: SuperRoot,
pending_progress: Vec<OptimisticBlock>,
step: u64,
) -> Self
pub const fn new( pre_state: SuperRoot, pending_progress: Vec<OptimisticBlock>, step: u64, ) -> Self
Create a new TransitionState with the given pre-state, pending progress, and step number.
Sourcepub fn hash(&self) -> B256
pub fn hash(&self) -> B256
Hashes the encoded TransitionState using keccak256.
Sourcepub fn payload_length(&self) -> usize
pub fn payload_length(&self) -> usize
Returns the RLP payload length of the TransitionState.